@@ -1,5 +1,6 @@
-#' Convert and translate Subdivision Names
+#' Convert and translate subdivision names
 #'
+#' @description
 #' Converts long subdivision names into different coding schemes and languages.
 #'
 #' @family dictionary
@@ -15,8 +16,8 @@
 #'
 #' @param sourcevar Vector which contains the subdivision names to be converted.
 #'
-#' @param origin,destination One of `"text"`, `"nuts"`, `"iso2"`,
-#'   `"codauto"` and `"cpro"`.
+#' @param origin,destination One of `"text"`, `"nuts"`, `"iso2"`, `"codauto"`
+#'   and `"cpro"`.
 #'
 #' @details
 #' If no match is found for any value, the function displays a warning and
@@ -58,8 +59,7 @@
 #' esp_dict_region_code(valsmix, destination = "iso2")
 #' }
 #'
-esp_dict_region_code <- function(sourcevar,
-                                 origin = "text",
+esp_dict_region_code <- function(sourcevar, origin = "text",
                                  destination = "text") {
   initsourcevar <- sourcevar
 
@@ -193,18 +193,19 @@ esp_dict_region_code <- function(sourcevar,
 #'
 #' @name esp_dict_translate
 #'
-#' @return [esp_dict_translate()] returns a character vector or a named
-#'   list with each of the possible names of each `sourcevar` on the required
-#'   language `lang`.
+#' @return
+#' [esp_dict_translate()] returns a `character` vector or a named `list` with
+#' each of the possible names of each `sourcevar` on the required language
+#' `lang`.
 #'
 #' @export
 #'
 #' @param lang Language of translation. Available languages are:
-#'   * `"es"`: Spanish
-#'   * `"en"`: English
-#'   * `"ca"`: Catalan
-#'   * `"ga"`: Galician
-#'   * `"eu"`: Basque
+#'   - `"es"`: Spanish
+#'   - `"en"`: English
+#'   - `"ca"`: Catalan
+#'   - `"ga"`: Galician
+#'   - `"eu"`: Basque
 #'
 #' @param all Logical. Should the function return all names or not?
 #'   On `FALSE` it returns a character vector. See **Value**.
